@@ -13,7 +13,7 @@ def threadhandler(infunc, list_items, max_workers=None):
     Returns:
         [type]: [description]
     """
-    log(f"-- Initiating thread for processing {len(list_items)} items with {infunc.__name__} function")
+    log(f"-- Initiating thread for processing {len(list_items)} items")
     list_results = []
     with ThreadPoolExecutor(max_workers=max_workers) as executor:
         # If items within list are tuples to unpack. If function requires more than 1 argument.
