@@ -3,8 +3,9 @@ import string
 import random
 
 
-def generate_random_string(string_length=None, words=1):
+def generate_random_string(string_length=None, words=1, freestyle=False):
     gen_words = []
+    words = random.randint(3, 20) if freestyle else 1
     for word in range(words):
         string_length = random.randint(2, 12) if string_length is None else string_length
         rando_word = ''.join(secrets.choice(string.ascii_uppercase + string.ascii_lowercase) for i in range(string_length))
